iris-grib
=========

|CirrusCI|_ |Coveralls|_ |conda-forge|_ |pypi|_ |License|_ |Commits|_ |Contributors|_

GRIB interface for `Iris <https://github.com/SciTools/iris>`_.

Code
----
iris-grib is licenced under the GNU Lesser General Public License (LGPLv3).

The full text of the licence can be found in the COPYING and COPYING.LESSER
files.

Copyright and licence
---------------------
iris-grib may be freely distributed, modified and used commercially under the
terms of its `GNU LGPLv3 license <COPYING.LESSER>`_.

\(C) British Crown Copyright 2010 - 2021, Met Office

.. |CirrusCI| image:: https://api.cirrus-ci.com/github/SciTools/iris-grib.svg?branch=master
.. _CirrusCI: https://cirrus-ci.com/github/SciTools/iris-grib

.. |Coveralls| image:: https://coveralls.io/repos/github/SciTools/iris-grib/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/SciTools/iris-grib?branch=master

.. |conda-forge| image:: https://img.shields.io/conda/vn/conda-forge/iris-grib?color=orange&label=conda-forge&logo=conda-forge&logoColor=white
.. _conda-forge: https://anaconda.org/conda-forge/iris-grib

.. |pypi| image:: https://img.shields.io/pypi/v/iris-grib?color=orange&label=pypi&logo=python&logoColor=white
.. _pypi: https://pypi.org/project/iris-grib

.. |License| image:: https://img.shields.io/github/license/SciTools/iris-grib?style=plastic
.. _License: https://github.com/SciTools/iris-grib/blob/master/COPYING

.. |Contributors| image:: https://img.shields.io/github/contributors/SciTools/iris-grib?style=plastic
.. _Contributors: https://github.com/SciTools/iris-grib/graphs/contributors

.. |Commits| image:: https://img.shields.io/github/commits-since/SciTools/iris-grib/latest.svg?style=plastic
.. _Commits: https://github.com/SciTools/iris-grib/commits/master